@@ -4,7 +4,7 @@ use warnings;
 
 # ABSTRACT: General-purpose content-addressed storage (CAS) for Catalyst
 
-our $VERSION = '0.994';
+our $VERSION = '0.995';
 
 use Moose;
 use Types::Standard qw(:all);
@@ -76,8 +76,10 @@ sub uri_find_Content {
   return undef;
 }
 
-sub fetch_content: Local {
-   my ($self, $c, $checksum, $filename) = @_;
+sub base :Chained :PathPrefix :CaptureArgs(0) {}
+
+sub fetch_content :Chained('base') :Args {
+  my ($self, $c, $checksum, $filename) = @_;
   
   my $disposition = 'inline;filename="' . $checksum . '"';
   
@@ -112,7 +114,7 @@ sub fetch_content: Local {
 }
 
 
-sub upload_content: Local  {
+sub upload_content :Chained('base') :Args {
   my ($self, $c) = @_;
 
   my $upload = $c->req->upload('Filedata') or die "no upload object";
@@ -122,7 +124,7 @@ sub upload_content: Local  {
 }
 
 
-sub upload_image: Local  {
+sub upload_image :Chained('base') :Args {
   my ($self, $c, $maxwidth, $maxheight) = @_;
 
   my $upload = $c->req->upload('Filedata') or die "no upload object";
@@ -268,7 +270,7 @@ sub add_size_info_image :Private {
 }
 
 
-sub upload_file : Local {
+sub upload_file :Chained('base') :Args {
   my ($self, $c) = @_;
   
   my $upload = $c->req->upload('Filedata') or die "no upload object";
@@ -296,7 +298,7 @@ sub safe_filename {
 }
 
 
-sub upload_echo_base64: Local  {
+sub upload_echo_base64 :Chained('base') :Args {
   my ($self, $c) = @_;
 
   my $upload = $c->req->upload('Filedata') or die "no upload object";
@@ -427,7 +429,6 @@ When there is no filename second arg supplied, the content-disposition is set li
 
   Content-Disposition: inline;filename="fdb379f7e9c8d0a1fcd3b5ee4233d88c5a4a023e"
 
-
 =head2 upload_file
 
 Works like C<upload_content>, but returns a JSON packet with additional metadata/information in
@@ -456,6 +457,16 @@ with all of the dependencies of L<GD>.
 This does nothing but accept a standard POST/Filedata upload and return it as base64 in a JSON
 packet within the JSON/object key C<echo_content>.
 
+=head2 base
+
+This is the base action of the Catalyst Chain behind this asset controller. So
+far it still is a fixed position, but we will allow in a later version to set
+the Chained base to any other action via configuration.
+
+You could override specific URLs inside the SimpleCAS with own controllers,
+you just chain to this base controller, but we would strongly advice to put
+those outside functionalities next to this controller.
+
 =head1 METHODS
 
 =head2 Content
